@@ -1,5 +1,8 @@
 package Lingua::PTD::BzDmp;
-$Lingua::PTD::BzDmp::VERSION = '1.13';
+$Lingua::PTD::BzDmp::VERSION = '1.14';
+use warnings;
+use strict;
+
 use parent 'Lingua::PTD';
 
 use IO::Compress::Bzip2     2.066  qw(bzip2 $Bzip2Error);
