@@ -1,5 +1,8 @@
 package Lingua::PTD::Dumper;
-$Lingua::PTD::Dumper::VERSION = '1.13';
+$Lingua::PTD::Dumper::VERSION = '1.14';
+use warnings;
+use strict;
+
 use parent 'Lingua::PTD';
 
 =encoding UTF-8
