@@ -1,5 +1,8 @@
 package Lingua::PTD::XzDmp;
-$Lingua::PTD::XzDmp::VERSION = '1.13';
+$Lingua::PTD::XzDmp::VERSION = '1.14';
+use warnings;
+use strict;
+
 use parent 'Lingua::PTD';
 
 use IO::Compress::Xz     2.066 qw(xz   $XzError);
